Welcome to slidingpuzzle's documentation!
=========================================

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   install
   slidingpuzzle
   slidingpuzzle.nn
   GitHub <https://www.github.com/entangledloops/slidingpuzzle>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
